# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.auth.v1beta1 import query_pb2 as cosmos_dot_auth_dot_v1beta1_dot_query__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/auth/v1beta1/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Accounts = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/Accounts',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsResponse.FromString,
                _registered_method=True)
        self.Account = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/Account',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountResponse.FromString,
                _registered_method=True)
        self.AccountAddressByID = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/AccountAddressByID',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountAddressByIDRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountAddressByIDResponse.FromString,
                _registered_method=True)
        self.Params = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/Params',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.ModuleAccounts = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/ModuleAccounts',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountsRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountsResponse.FromString,
                _registered_method=True)
        self.ModuleAccountByName = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/ModuleAccountByName',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountByNameRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountByNameResponse.FromString,
                _registered_method=True)
        self.Bech32Prefix = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/Bech32Prefix',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.Bech32PrefixRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.Bech32PrefixResponse.FromString,
                _registered_method=True)
        self.AddressBytesToString = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/AddressBytesToString',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressBytesToStringRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressBytesToStringResponse.FromString,
                _registered_method=True)
        self.AddressStringToBytes = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/AddressStringToBytes',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressStringToBytesRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressStringToBytesResponse.FromString,
                _registered_method=True)
        self.AccountInfo = channel.unary_unary(
                '/cosmos.auth.v1beta1.Query/AccountInfo',
                request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountInfoRequest.SerializeToString,
                response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountInfoResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Accounts(self, request, context):
        """Accounts returns all the existing accounts.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.

        Since: cosmos-sdk 0.43
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Account(self, request, context):
        """Account returns account details based on address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountAddressByID(self, request, context):
        """AccountAddressByID returns account address based on account number.

        Since: cosmos-sdk 0.46.2
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries all parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModuleAccounts(self, request, context):
        """ModuleAccounts returns all the existing module accounts.

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModuleAccountByName(self, request, context):
        """ModuleAccountByName returns the module account info by module name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Bech32Prefix(self, request, context):
        """Bech32Prefix queries bech32Prefix

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddressBytesToString(self, request, context):
        """AddressBytesToString converts Account Address bytes to string

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddressStringToBytes(self, request, context):
        """AddressStringToBytes converts Address string to bytes

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountInfo(self, request, context):
        """AccountInfo queries account info which is common to all account types.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Accounts': grpc.unary_unary_rpc_method_handler(
                    servicer.Accounts,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsResponse.SerializeToString,
            ),
            'Account': grpc.unary_unary_rpc_method_handler(
                    servicer.Account,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountResponse.SerializeToString,
            ),
            'AccountAddressByID': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountAddressByID,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountAddressByIDRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountAddressByIDResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'ModuleAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleAccounts,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountsRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountsResponse.SerializeToString,
            ),
            'ModuleAccountByName': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleAccountByName,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountByNameRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountByNameResponse.SerializeToString,
            ),
            'Bech32Prefix': grpc.unary_unary_rpc_method_handler(
                    servicer.Bech32Prefix,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.Bech32PrefixRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.Bech32PrefixResponse.SerializeToString,
            ),
            'AddressBytesToString': grpc.unary_unary_rpc_method_handler(
                    servicer.AddressBytesToString,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressBytesToStringRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressBytesToStringResponse.SerializeToString,
            ),
            'AddressStringToBytes': grpc.unary_unary_rpc_method_handler(
                    servicer.AddressStringToBytes,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressStringToBytesRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressStringToBytesResponse.SerializeToString,
            ),
            'AccountInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountInfo,
                    request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountInfoRequest.FromString,
                    response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.auth.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.auth.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Accounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/Accounts',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Account(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/Account',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AccountAddressByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/AccountAddressByID',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountAddressByIDRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountAddressByIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/Params',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModuleAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/ModuleAccounts',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountsRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModuleAccountByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/ModuleAccountByName',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountByNameRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryModuleAccountByNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Bech32Prefix(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/Bech32Prefix',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.Bech32PrefixRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.Bech32PrefixResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddressBytesToString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/AddressBytesToString',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressBytesToStringRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressBytesToStringResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddressStringToBytes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/AddressStringToBytes',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressStringToBytesRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.AddressStringToBytesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AccountInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.auth.v1beta1.Query/AccountInfo',
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountInfoRequest.SerializeToString,
            cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("hard_cap_for_markets",)
    HARD_CAP_FOR_MARKETS_FIELD_NUMBER: _ClassVar[int]
    hard_cap_for_markets: int
    def __init__(self, hard_cap_for_markets: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.vault import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.vault import share_pb2 as _share_pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as _vault_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("vaults", "default_quoting_params")
    VAULTS_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_QUOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    vaults: _containers.RepeatedCompositeFieldContainer[Vault]
    default_quoting_params: _params_pb2.QuotingParams
    def __init__(self, vaults: _Optional[_Iterable[_Union[Vault, _Mapping]]] = ..., default_quoting_params: _Optional[_Union[_params_pb2.QuotingParams, _Mapping]] = ...) -> None: ...

class Vault(_message.Message):
    __slots__ = ("vault_id", "total_shares", "owner_shares", "quoting_params", "most_recent_client_ids")
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SHARES_FIELD_NUMBER: _ClassVar[int]
    OWNER_SHARES_FIELD_NUMBER: _ClassVar[int]
    QUOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    MOST_RECENT_CLIENT_IDS_FIELD_NUMBER: _ClassVar[int]
    vault_id: _vault_pb2.VaultId
    total_shares: _share_pb2.NumShares
    owner_shares: _containers.RepeatedCompositeFieldContainer[_share_pb2.OwnerShare]
    quoting_params: _params_pb2.QuotingParams
    most_recent_client_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., total_shares: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ..., owner_shares: _Optional[_Iterable[_Union[_share_pb2.OwnerShare, _Mapping]]] = ..., quoting_params: _Optional[_Union[_params_pb2.QuotingParams, _Mapping]] = ..., most_recent_client_ids: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/listing/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/listing/query.proto\x12\x14\x64ydxprotocol.listing\"\x15\n\x13QueryMarketsHardCap\"/\n\x1bQueryMarketsHardCapResponse\x12\x10\n\x08hard_cap\x18\x01 \x01(\r2w\n\x05Query\x12n\n\x0eMarketsHardCap\x12).dydxprotocol.listing.QueryMarketsHardCap\x1a\x31.dydxprotocol.listing.QueryMarketsHardCapResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.listing.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/types'
  _globals['_QUERYMARKETSHARDCAP']._serialized_start=58
  _globals['_QUERYMARKETSHARDCAP']._serialized_end=79
  _globals['_QUERYMARKETSHARDCAPRESPONSE']._serialized_start=81
  _globals['_QUERYMARKETSHARDCAPRESPONSE']._serialized_end=128
  _globals['_QUERY']._serialized_start=130
  _globals['_QUERY']._serialized_end=249
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("bech32_prefix", "module_account_permissions", "authority")
    BECH32_PREFIX_FIELD_NUMBER: _ClassVar[int]
    MODULE_ACCOUNT_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    bech32_prefix: str
    module_account_permissions: _containers.RepeatedCompositeFieldContainer[ModuleAccountPermission]
    authority: str
    def __init__(self, bech32_prefix: _Optional[str] = ..., module_account_permissions: _Optional[_Iterable[_Union[ModuleAccountPermission, _Mapping]]] = ..., authority: _Optional[str] = ...) -> None: ...

class ModuleAccountPermission(_message.Message):
    __slots__ = ("account", "permissions")
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    account: str
    permissions: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, account: _Optional[str] = ..., permissions: _Optional[_Iterable[str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.clob import query_pb2 as dydxprotocol_dot_clob_dot_query__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/clob/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClobPair = channel.unary_unary(
                '/dydxprotocol.clob.Query/ClobPair',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryGetClobPairRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryClobPairResponse.FromString,
                _registered_method=True)
        self.ClobPairAll = channel.unary_unary(
                '/dydxprotocol.clob.Query/ClobPairAll',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryAllClobPairRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryClobPairAllResponse.FromString,
                _registered_method=True)
        self.MevNodeToNodeCalculation = channel.unary_unary(
                '/dydxprotocol.clob.Query/MevNodeToNodeCalculation',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.MevNodeToNodeCalculationRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.MevNodeToNodeCalculationResponse.FromString,
                _registered_method=True)
        self.EquityTierLimitConfiguration = channel.unary_unary(
                '/dydxprotocol.clob.Query/EquityTierLimitConfiguration',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryEquityTierLimitConfigurationRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryEquityTierLimitConfigurationResponse.FromString,
                _registered_method=True)
        self.BlockRateLimitConfiguration = channel.unary_unary(
                '/dydxprotocol.clob.Query/BlockRateLimitConfiguration',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryBlockRateLimitConfigurationRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryBlockRateLimitConfigurationResponse.FromString,
                _registered_method=True)
        self.LiquidationsConfiguration = channel.unary_unary(
                '/dydxprotocol.clob.Query/LiquidationsConfiguration',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryLiquidationsConfigurationRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryLiquidationsConfigurationResponse.FromString,
                _registered_method=True)
        self.StatefulOrder = channel.unary_unary(
                '/dydxprotocol.clob.Query/StatefulOrder',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryStatefulOrderRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryStatefulOrderResponse.FromString,
                _registered_method=True)
        self.StreamOrderbookUpdates = channel.unary_stream(
                '/dydxprotocol.clob.Query/StreamOrderbookUpdates',
                request_serializer=dydxprotocol_dot_clob_dot_query__pb2.StreamOrderbookUpdatesRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_query__pb2.StreamOrderbookUpdatesResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def ClobPair(self, request, context):
        """Queries a ClobPair by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClobPairAll(self, request, context):
        """Queries a list of ClobPair items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MevNodeToNodeCalculation(self, request, context):
        """Runs the MEV node <> node calculation with the provided parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EquityTierLimitConfiguration(self, request, context):
        """Queries EquityTierLimitConfiguration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlockRateLimitConfiguration(self, request, context):
        """Queries BlockRateLimitConfiguration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LiquidationsConfiguration(self, request, context):
        """Queries LiquidationsConfiguration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatefulOrder(self, request, context):
        """Queries the stateful order for a given order id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrderbookUpdates(self, request, context):
        """GRPC Streams

        Streams orderbook updates. Updates contain orderbook data
        such as order placements, updates, and fills.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ClobPair': grpc.unary_unary_rpc_method_handler(
                    servicer.ClobPair,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryGetClobPairRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryClobPairResponse.SerializeToString,
            ),
            'ClobPairAll': grpc.unary_unary_rpc_method_handler(
                    servicer.ClobPairAll,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryAllClobPairRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryClobPairAllResponse.SerializeToString,
            ),
            'MevNodeToNodeCalculation': grpc.unary_unary_rpc_method_handler(
                    servicer.MevNodeToNodeCalculation,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.MevNodeToNodeCalculationRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.MevNodeToNodeCalculationResponse.SerializeToString,
            ),
            'EquityTierLimitConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.EquityTierLimitConfiguration,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryEquityTierLimitConfigurationRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryEquityTierLimitConfigurationResponse.SerializeToString,
            ),
            'BlockRateLimitConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.BlockRateLimitConfiguration,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryBlockRateLimitConfigurationRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryBlockRateLimitConfigurationResponse.SerializeToString,
            ),
            'LiquidationsConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.LiquidationsConfiguration,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryLiquidationsConfigurationRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryLiquidationsConfigurationResponse.SerializeToString,
            ),
            'StatefulOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.StatefulOrder,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.QueryStatefulOrderRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.QueryStatefulOrderResponse.SerializeToString,
            ),
            'StreamOrderbookUpdates': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrderbookUpdates,
                    request_deserializer=dydxprotocol_dot_clob_dot_query__pb2.StreamOrderbookUpdatesRequest.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_query__pb2.StreamOrderbookUpdatesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.clob.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.clob.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def ClobPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Query/ClobPair',
            dydxprotocol_dot_clob_dot_query__pb2.QueryGetClobPairRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.QueryClobPairResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClobPairAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Query/ClobPairAll',
            dydxprotocol_dot_clob_dot_query__pb2.QueryAllClobPairRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.QueryClobPairAllResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MevNodeToNodeCalculation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Query/MevNodeToNodeCalculation',
            dydxprotocol_dot_clob_dot_query__pb2.MevNodeToNodeCalculationRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.MevNodeToNodeCalculationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EquityTierLimitConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Query/EquityTierLimitConfiguration',
            dydxprotocol_dot_clob_dot_query__pb2.QueryEquityTierLimitConfigurationRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.QueryEquityTierLimitConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BlockRateLimitConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Query/BlockRateLimitConfiguration',
            dydxprotocol_dot_clob_dot_query__pb2.QueryBlockRateLimitConfigurationRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.QueryBlockRateLimitConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LiquidationsConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Query/LiquidationsConfiguration',
            dydxprotocol_dot_clob_dot_query__pb2.QueryLiquidationsConfigurationRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.QueryLiquidationsConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StatefulOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Query/StatefulOrder',
            dydxprotocol_dot_clob_dot_query__pb2.QueryStatefulOrderRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.QueryStatefulOrderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamOrderbookUpdates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/dydxprotocol.clob.Query/StreamOrderbookUpdates',
            dydxprotocol_dot_clob_dot_query__pb2.StreamOrderbookUpdatesRequest.SerializeToString,
            dydxprotocol_dot_clob_dot_query__pb2.StreamOrderbookUpdatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from v4_proto.cosmos.query.v1 import query_pb2 as _query_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FileDescriptorsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FileDescriptorsResponse(_message.Message):
    __slots__ = ("files",)
    FILES_FIELD_NUMBER: _ClassVar[int]
    files: _containers.RepeatedCompositeFieldContainer[_descriptor_pb2.FileDescriptorProto]
    def __init__(self, files: _Optional[_Iterable[_Union[_descriptor_pb2.FileDescriptorProto, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/internal/kv/v1beta1/kv.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cosmos/store/internal/kv/v1beta1/kv.proto\x12 cosmos.store.internal.kv.v1beta1\x1a\x14gogoproto/gogo.proto\"D\n\x05Pairs\x12;\n\x05pairs\x18\x01 \x03(\x0b\x32&.cosmos.store.internal.kv.v1beta1.PairB\x04\xc8\xde\x1f\x00\"\"\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x42 Z\x1e\x63osmossdk.io/store/internal/kvb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.internal.kv.v1beta1.kv_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\036cosmossdk.io/store/internal/kv'
  _globals['_PAIRS'].fields_by_name['pairs']._loaded_options = None
  _globals['_PAIRS'].fields_by_name['pairs']._serialized_options = b'\310\336\037\000'
  _globals['_PAIRS']._serialized_start=101
  _globals['_PAIRS']._serialized_end=169
  _globals['_PAIR']._serialized_start=171
  _globals['_PAIR']._serialized_end=205
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MarketMapperRevShareDetails(_message.Message):
    __slots__ = ("expiration_ts",)
    EXPIRATION_TS_FIELD_NUMBER: _ClassVar[int]
    expiration_ts: int
    def __init__(self, expiration_ts: _Optional[int] = ...) -> None: ...



from v4_proto.dydxprotocol.indexer.protocol.v1 import subaccount_pb2 as _subaccount_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrderbookMessage(_message.Message):
    __slots__ = ("contents", "clob_pair_id", "version")
    CONTENTS_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    contents: str
    clob_pair_id: str
    version: str
    def __init__(self, contents: _Optional[str] = ..., clob_pair_id: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class SubaccountMessage(_message.Message):
    __slots__ = ("block_height", "transaction_index", "event_index", "contents", "subaccount_id", "version")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_INDEX_FIELD_NUMBER: _ClassVar[int]
    EVENT_INDEX_FIELD_NUMBER: _ClassVar[int]
    CONTENTS_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block_height: str
    transaction_index: int
    event_index: int
    contents: str
    subaccount_id: _subaccount_pb2.IndexerSubaccountId
    version: str
    def __init__(self, block_height: _Optional[str] = ..., transaction_index: _Optional[int] = ..., event_index: _Optional[int] = ..., contents: _Optional[str] = ..., subaccount_id: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., version: _Optional[str] = ...) -> None: ...

class TradeMessage(_message.Message):
    __slots__ = ("block_height", "contents", "clob_pair_id", "version")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    CONTENTS_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block_height: str
    contents: str
    clob_pair_id: str
    version: str
    def __init__(self, block_height: _Optional[str] = ..., contents: _Optional[str] = ..., clob_pair_id: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class MarketMessage(_message.Message):
    __slots__ = ("contents", "version")
    CONTENTS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    contents: str
    version: str
    def __init__(self, contents: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class CandleMessage(_message.Message):
    __slots__ = ("contents", "clob_pair_id", "resolution", "version")
    class Resolution(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ONE_MINUTE: _ClassVar[CandleMessage.Resolution]
        FIVE_MINUTES: _ClassVar[CandleMessage.Resolution]
        FIFTEEN_MINUTES: _ClassVar[CandleMessage.Resolution]
        THIRTY_MINUTES: _ClassVar[CandleMessage.Resolution]
        ONE_HOUR: _ClassVar[CandleMessage.Resolution]
        FOUR_HOURS: _ClassVar[CandleMessage.Resolution]
        ONE_DAY: _ClassVar[CandleMessage.Resolution]
    ONE_MINUTE: CandleMessage.Resolution
    FIVE_MINUTES: CandleMessage.Resolution
    FIFTEEN_MINUTES: CandleMessage.Resolution
    THIRTY_MINUTES: CandleMessage.Resolution
    ONE_HOUR: CandleMessage.Resolution
    FOUR_HOURS: CandleMessage.Resolution
    ONE_DAY: CandleMessage.Resolution
    CONTENTS_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    contents: str
    clob_pair_id: str
    resolution: CandleMessage.Resolution
    version: str
    def __init__(self, contents: _Optional[str] = ..., clob_pair_id: _Optional[str] = ..., resolution: _Optional[_Union[CandleMessage.Resolution, str]] = ..., version: _Optional[str] = ...) -> None: ...

class BlockHeightMessage(_message.Message):
    __slots__ = ("block_height", "time", "version")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block_height: str
    time: str
    version: str
    def __init__(self, block_height: _Optional[str] = ..., time: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as _block_rate_limit_config_pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as _clob_pair_pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as _equity_tier_limit_config_pb2
from v4_proto.dydxprotocol.clob import matches_pb2 as _matches_pb2
from v4_proto.dydxprotocol.clob import order_pb2 as _order_pb2
from v4_proto.dydxprotocol.clob import order_removals_pb2 as _order_removals_pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as _liquidations_config_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateClobPair(_message.Message):
    __slots__ = ("authority", "clob_pair")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    authority: str
    clob_pair: _clob_pair_pb2.ClobPair
    def __init__(self, authority: _Optional[str] = ..., clob_pair: _Optional[_Union[_clob_pair_pb2.ClobPair, _Mapping]] = ...) -> None: ...

class MsgCreateClobPairResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgProposedOperations(_message.Message):
    __slots__ = ("operations_queue",)
    OPERATIONS_QUEUE_FIELD_NUMBER: _ClassVar[int]
    operations_queue: _containers.RepeatedCompositeFieldContainer[OperationRaw]
    def __init__(self, operations_queue: _Optional[_Iterable[_Union[OperationRaw, _Mapping]]] = ...) -> None: ...

class MsgProposedOperationsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgPlaceOrder(_message.Message):
    __slots__ = ("order",)
    ORDER_FIELD_NUMBER: _ClassVar[int]
    order: _order_pb2.Order
    def __init__(self, order: _Optional[_Union[_order_pb2.Order, _Mapping]] = ...) -> None: ...

class MsgPlaceOrderResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCancelOrder(_message.Message):
    __slots__ = ("order_id", "good_til_block", "good_til_block_time")
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    GOOD_TIL_BLOCK_FIELD_NUMBER: _ClassVar[int]
    GOOD_TIL_BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    order_id: _order_pb2.OrderId
    good_til_block: int
    good_til_block_time: int
    def __init__(self, order_id: _Optional[_Union[_order_pb2.OrderId, _Mapping]] = ..., good_til_block: _Optional[int] = ..., good_til_block_time: _Optional[int] = ...) -> None: ...

class MsgCancelOrderResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgBatchCancel(_message.Message):
    __slots__ = ("subaccount_id", "short_term_cancels", "good_til_block")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    SHORT_TERM_CANCELS_FIELD_NUMBER: _ClassVar[int]
    GOOD_TIL_BLOCK_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.SubaccountId
    short_term_cancels: _containers.RepeatedCompositeFieldContainer[OrderBatch]
    good_til_block: int
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., short_term_cancels: _Optional[_Iterable[_Union[OrderBatch, _Mapping]]] = ..., good_til_block: _Optional[int] = ...) -> None: ...

class OrderBatch(_message.Message):
    __slots__ = ("clob_pair_id", "client_ids")
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_IDS_FIELD_NUMBER: _ClassVar[int]
    clob_pair_id: int
    client_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, clob_pair_id: _Optional[int] = ..., client_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class MsgBatchCancelResponse(_message.Message):
    __slots__ = ("short_term_succeeded", "short_term_failed")
    SHORT_TERM_SUCCEEDED_FIELD_NUMBER: _ClassVar[int]
    SHORT_TERM_FAILED_FIELD_NUMBER: _ClassVar[int]
    short_term_succeeded: _containers.RepeatedCompositeFieldContainer[OrderBatch]
    short_term_failed: _containers.RepeatedCompositeFieldContainer[OrderBatch]
    def __init__(self, short_term_succeeded: _Optional[_Iterable[_Union[OrderBatch, _Mapping]]] = ..., short_term_failed: _Optional[_Iterable[_Union[OrderBatch, _Mapping]]] = ...) -> None: ...

class MsgUpdateClobPair(_message.Message):
    __slots__ = ("authority", "clob_pair")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    authority: str
    clob_pair: _clob_pair_pb2.ClobPair
    def __init__(self, authority: _Optional[str] = ..., clob_pair: _Optional[_Union[_clob_pair_pb2.ClobPair, _Mapping]] = ...) -> None: ...

class MsgUpdateClobPairResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class OperationRaw(_message.Message):
    __slots__ = ("match", "short_term_order_placement", "order_removal")
    MATCH_FIELD_NUMBER: _ClassVar[int]
    SHORT_TERM_ORDER_PLACEMENT_FIELD_NUMBER: _ClassVar[int]
    ORDER_REMOVAL_FIELD_NUMBER: _ClassVar[int]
    match: _matches_pb2.ClobMatch
    short_term_order_placement: bytes
    order_removal: _order_removals_pb2.OrderRemoval
    def __init__(self, match: _Optional[_Union[_matches_pb2.ClobMatch, _Mapping]] = ..., short_term_order_placement: _Optional[bytes] = ..., order_removal: _Optional[_Union[_order_removals_pb2.OrderRemoval, _Mapping]] = ...) -> None: ...

class MsgUpdateEquityTierLimitConfiguration(_message.Message):
    __slots__ = ("authority", "equity_tier_limit_config")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    EQUITY_TIER_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    authority: str
    equity_tier_limit_config: _equity_tier_limit_config_pb2.EquityTierLimitConfiguration
    def __init__(self, authority: _Optional[str] = ..., equity_tier_limit_config: _Optional[_Union[_equity_tier_limit_config_pb2.EquityTierLimitConfiguration, _Mapping]] = ...) -> None: ...

class MsgUpdateEquityTierLimitConfigurationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateBlockRateLimitConfiguration(_message.Message):
    __slots__ = ("authority", "block_rate_limit_config")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    BLOCK_RATE_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    authority: str
    block_rate_limit_config: _block_rate_limit_config_pb2.BlockRateLimitConfiguration
    def __init__(self, authority: _Optional[str] = ..., block_rate_limit_config: _Optional[_Union[_block_rate_limit_config_pb2.BlockRateLimitConfiguration, _Mapping]] = ...) -> None: ...

class MsgUpdateBlockRateLimitConfigurationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateLiquidationsConfig(_message.Message):
    __slots__ = ("authority", "liquidations_config")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    LIQUIDATIONS_CONFIG_FIELD_NUMBER: _ClassVar[int]
    authority: str
    liquidations_config: _liquidations_config_pb2.LiquidationsConfig
    def __init__(self, authority: _Optional[str] = ..., liquidations_config: _Optional[_Union[_liquidations_config_pb2.LiquidationsConfig, _Mapping]] = ...) -> None: ...

class MsgUpdateLiquidationsConfigResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/orm/query/v1alpha1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/orm/query/v1alpha1/query.proto\x12\x19\x63osmos.orm.query.v1alpha1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19google/protobuf/any.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\"h\n\nGetRequest\x12\x14\n\x0cmessage_name\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\t\x12\x35\n\x06values\x18\x03 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValue\"3\n\x0bGetResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\xab\x03\n\x0bListRequest\x12\x14\n\x0cmessage_name\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\t\x12?\n\x06prefix\x18\x03 \x01(\x0b\x32-.cosmos.orm.query.v1alpha1.ListRequest.PrefixH\x00\x12=\n\x05range\x18\x04 \x01(\x0b\x32,.cosmos.orm.query.v1alpha1.ListRequest.RangeH\x00\x12:\n\npagination\x18\x05 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1a?\n\x06Prefix\x12\x35\n\x06values\x18\x01 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValue\x1aq\n\x05Range\x12\x34\n\x05start\x18\x01 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValue\x12\x32\n\x03\x65nd\x18\x02 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueB\x07\n\x05query\"r\n\x0cListResponse\x12%\n\x07results\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12;\n\npagination\x18\x05 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xd4\x01\n\nIndexValue\x12\x0e\n\x04uint\x18\x01 \x01(\x04H\x00\x12\r\n\x03int\x18\x02 \x01(\x03H\x00\x12\r\n\x03str\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\x04 \x01(\x0cH\x00\x12\x0e\n\x04\x65num\x18\x05 \x01(\tH\x00\x12\x0e\n\x04\x62ool\x18\x06 \x01(\x08H\x00\x12/\n\ttimestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12-\n\x08\x64uration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x42\x07\n\x05value2\xb6\x01\n\x05Query\x12T\n\x03Get\x12%.cosmos.orm.query.v1alpha1.GetRequest\x1a&.cosmos.orm.query.v1alpha1.GetResponse\x12W\n\x04List\x12&.cosmos.orm.query.v1alpha1.ListRequest\x1a\'.cosmos.orm.query.v1alpha1.ListResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.orm.query.v1alpha1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETREQUEST']._serialized_start=204
  _globals['_GETREQUEST']._serialized_end=308
  _globals['_GETRESPONSE']._serialized_start=310
  _globals['_GETRESPONSE']._serialized_end=361
  _globals['_LISTREQUEST']._serialized_start=364
  _globals['_LISTREQUEST']._serialized_end=791
  _globals['_LISTREQUEST_PREFIX']._serialized_start=604
  _globals['_LISTREQUEST_PREFIX']._serialized_end=667
  _globals['_LISTREQUEST_RANGE']._serialized_start=669
  _globals['_LISTREQUEST_RANGE']._serialized_end=782
  _globals['_LISTRESPONSE']._serialized_start=793
  _globals['_LISTRESPONSE']._serialized_end=907
  _globals['_INDEXVALUE']._serialized_start=910
  _globals['_INDEXVALUE']._serialized_end=1122
  _globals['_QUERY']._serialized_start=1125
  _globals['_QUERY']._serialized_end=1307
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/assets/asset.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/assets/asset.proto\x12\x13\x64ydxprotocol.assets\"\x8c\x01\n\x05\x41sset\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x65nom_exponent\x18\x04 \x01(\x11\x12\x12\n\nhas_market\x18\x05 \x01(\x08\x12\x11\n\tmarket_id\x18\x06 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x07 \x01(\x11\x42:Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.assets.asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/types'
  _globals['_ASSET']._serialized_start=57
  _globals['_ASSET']._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/bank/v1beta1/tx.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\x8c\x02\n\x07MsgSend\x12.\n\x0c\x66rom_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12,\n\nto_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12q\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01:0\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0*\x12\x63osmos-sdk/MsgSend\"\x11\n\x0fMsgSendResponse\"\xab\x01\n\x0cMsgMultiSend\x12\x35\n\x06inputs\x18\x01 \x03(\x0b\x32\x1a.cosmos.bank.v1beta1.InputB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x37\n\x07outputs\x18\x02 \x03(\x0b\x32\x1b.cosmos.bank.v1beta1.OutputB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:+\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06inputs\x8a\xe7\xb0*\x17\x63osmos-sdk/MsgMultiSend\"\x16\n\x14MsgMultiSendResponse\"\xac\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:4\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*!cosmos-sdk/x/bank/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xc2\x01\n\x11MsgSetSendEnabled\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x0csend_enabled\x18\x02 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabled\x12\x17\n\x0fuse_default_for\x18\x03 \x03(\t:/\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x1c\x63osmos-sdk/MsgSetSendEnabled\"\x1b\n\x19MsgSetSendEnabledResponse2\x81\x03\n\x03Msg\x12J\n\x04Send\x12\x1c.cosmos.bank.v1beta1.MsgSend\x1a$.cosmos.bank.v1beta1.MsgSendResponse\x12Y\n\tMultiSend\x12!.cosmos.bank.v1beta1.MsgMultiSend\x1a).cosmos.bank.v1beta1.MsgMultiSendResponse\x12\x62\n\x0cUpdateParams\x12$.cosmos.bank.v1beta1.MsgUpdateParams\x1a,.cosmos.bank.v1beta1.MsgUpdateParamsResponse\x12h\n\x0eSetSendEnabled\x12&.cosmos.bank.v1beta1.MsgSetSendEnabled\x1a..cosmos.bank.v1beta1.MsgSetSendEnabledResponse\x1a\x05\x80\xe7\xb0*\x01\x42+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _globals['_MSGSEND'].fields_by_name['from_address']._loaded_options = None
  _globals['_MSGSEND'].fields_by_name['from_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSEND'].fields_by_name['to_address']._loaded_options = None
  _globals['_MSGSEND'].fields_by_name['to_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSEND'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGSEND'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGSEND']._loaded_options = None
  _globals['_MSGSEND']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\014from_address\212\347\260*\022cosmos-sdk/MsgSend'
  _globals['_MSGMULTISEND'].fields_by_name['inputs']._loaded_options = None
  _globals['_MSGMULTISEND'].fields_by_name['inputs']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGMULTISEND'].fields_by_name['outputs']._loaded_options = None
  _globals['_MSGMULTISEND'].fields_by_name['outputs']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGMULTISEND']._loaded_options = None
  _globals['_MSGMULTISEND']._serialized_options = b'\350\240\037\000\202\347\260*\006inputs\212\347\260*\027cosmos-sdk/MsgMultiSend'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*!cosmos-sdk/x/bank/MsgUpdateParams'
  _globals['_MSGSETSENDENABLED'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETSENDENABLED'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETSENDENABLED']._loaded_options = None
  _globals['_MSGSETSENDENABLED']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\034cosmos-sdk/MsgSetSendEnabled'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSEND']._serialized_start=211
  _globals['_MSGSEND']._serialized_end=479
  _globals['_MSGSENDRESPONSE']._serialized_start=481
  _globals['_MSGSENDRESPONSE']._serialized_end=498
  _globals['_MSGMULTISEND']._serialized_start=501
  _globals['_MSGMULTISEND']._serialized_end=672
  _globals['_MSGMULTISENDRESPONSE']._serialized_start=674
  _globals['_MSGMULTISENDRESPONSE']._serialized_end=696
  _globals['_MSGUPDATEPARAMS']._serialized_start=699
  _globals['_MSGUPDATEPARAMS']._serialized_end=871
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=873
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=898
  _globals['_MSGSETSENDENABLED']._serialized_start=901
  _globals['_MSGSETSENDENABLED']._serialized_end=1095
  _globals['_MSGSETSENDENABLEDRESPONSE']._serialized_start=1097
  _globals['_MSGSETSENDENABLEDRESPONSE']._serialized_end=1124
  _globals['_MSG']._serialized_start=1127
  _globals['_MSG']._serialized_end=1512
# @@protoc_insertion_point(module_scope)



from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendAuthorization(_message.Message):
    __slots__ = ("spend_limit", "allow_list")
    SPEND_LIMIT_FIELD_NUMBER: _ClassVar[int]
    ALLOW_LIST_FIELD_NUMBER: _ClassVar[int]
    spend_limit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    allow_list: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, spend_limit: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., allow_list: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/subaccounts/streaming.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dydxprotocol/subaccounts/streaming.proto\x12\x18\x64ydxprotocol.subaccounts\x1a)dydxprotocol/subaccounts/subaccount.proto\"\x99\x02\n\x16StreamSubaccountUpdate\x12=\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12Z\n\x1bupdated_perpetual_positions\x18\x02 \x03(\x0b\x32\x35.dydxprotocol.subaccounts.SubaccountPerpetualPosition\x12R\n\x17updated_asset_positions\x18\x03 \x03(\x0b\x32\x31.dydxprotocol.subaccounts.SubaccountAssetPosition\x12\x10\n\x08snapshot\x18\x04 \x01(\x08\"E\n\x1bSubaccountPerpetualPosition\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x10\n\x08quantums\x18\x02 \x01(\x04\"=\n\x17SubaccountAssetPosition\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\r\x12\x10\n\x08quantums\x18\x02 \x01(\x04\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.subaccounts.streaming_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/types'
  _globals['_STREAMSUBACCOUNTUPDATE']._serialized_start=114
  _globals['_STREAMSUBACCOUNTUPDATE']._serialized_end=395
  _globals['_SUBACCOUNTPERPETUALPOSITION']._serialized_start=397
  _globals['_SUBACCOUNTPERPETUALPOSITION']._serialized_end=466
  _globals['_SUBACCOUNTASSETPOSITION']._serialized_start=468
  _globals['_SUBACCOUNTASSETPOSITION']._serialized_end=529
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PerpetualPosition(_message.Message):
    __slots__ = ("perpetual_id", "quantums", "funding_index", "quote_balance")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    FUNDING_INDEX_FIELD_NUMBER: _ClassVar[int]
    QUOTE_BALANCE_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    quantums: bytes
    funding_index: bytes
    quote_balance: bytes
    def __init__(self, perpetual_id: _Optional[int] = ..., quantums: _Optional[bytes] = ..., funding_index: _Optional[bytes] = ..., quote_balance: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/indexer/protocol/v1/subaccount.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1dydxprotocol/indexer/protocol/v1/subaccount.proto\x12 dydxprotocol.indexer.protocol.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"N\n\x13IndexerSubaccountId\x12\'\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06number\x18\x02 \x01(\r\"\xd0\x02\n\x18IndexerPerpetualPosition\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12Z\n\x08quantums\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12_\n\rfunding_index\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x61\n\x0f\x66unding_payment\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\x93\x01\n\x14IndexerAssetPosition\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\r\x12Z\n\x08quantums\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\r\n\x05index\x18\x03 \x01(\x04\x42\x45ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.protocol.v1.subaccount_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/types'
  _globals['_INDEXERSUBACCOUNTID'].fields_by_name['owner']._loaded_options = None
  _globals['_INDEXERSUBACCOUNTID'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_INDEXERPERPETUALPOSITION'].fields_by_name['quantums']._loaded_options = None
  _globals['_INDEXERPERPETUALPOSITION'].fields_by_name['quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_INDEXERPERPETUALPOSITION'].fields_by_name['funding_index']._loaded_options = None
  _globals['_INDEXERPERPETUALPOSITION'].fields_by_name['funding_index']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_INDEXERPERPETUALPOSITION'].fields_by_name['funding_payment']._loaded_options = None
  _globals['_INDEXERPERPETUALPOSITION'].fields_by_name['funding_payment']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_INDEXERASSETPOSITION'].fields_by_name['quantums']._loaded_options = None
  _globals['_INDEXERASSETPOSITION'].fields_by_name['quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_INDEXERSUBACCOUNTID']._serialized_start=136
  _globals['_INDEXERSUBACCOUNTID']._serialized_end=214
  _globals['_INDEXERPERPETUALPOSITION']._serialized_start=217
  _globals['_INDEXERPERPETUALPOSITION']._serialized_end=553
  _globals['_INDEXERASSETPOSITION']._serialized_start=556
  _globals['_INDEXERASSETPOSITION']._serialized_end=703
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/feetiers/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.feetiers import params_pb2 as dydxprotocol_dot_feetiers_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/feetiers/query.proto\x12\x15\x64ydxprotocol.feetiers\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/feetiers/params.proto\" \n\x1eQueryPerpetualFeeParamsRequest\"b\n\x1fQueryPerpetualFeeParamsResponse\x12?\n\x06params\x18\x01 \x01(\x0b\x32).dydxprotocol.feetiers.PerpetualFeeParamsB\x04\xc8\xde\x1f\x00\"A\n\x17QueryUserFeeTierRequest\x12&\n\x04user\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"`\n\x18QueryUserFeeTierResponse\x12\r\n\x05index\x18\x01 \x01(\r\x12\x35\n\x04tier\x18\x02 \x01(\x0b\x32\'.dydxprotocol.feetiers.PerpetualFeeTier2\xe7\x02\n\x05Query\x12\xbb\x01\n\x12PerpetualFeeParams\x12\x35.dydxprotocol.feetiers.QueryPerpetualFeeParamsRequest\x1a\x36.dydxprotocol.feetiers.QueryPerpetualFeeParamsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/v4/feetiers/perpetual_fee_params\x12\x9f\x01\n\x0bUserFeeTier\x12..dydxprotocol.feetiers.QueryUserFeeTierRequest\x1a/.dydxprotocol.feetiers.QueryUserFeeTierResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/dydxprotocol/v4/feetiers/user_fee_tierB<Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.feetiers.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/types'
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUSERFEETIERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_QUERYUSERFEETIERREQUEST'].fields_by_name['user']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['PerpetualFeeParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PerpetualFeeParams']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/v4/feetiers/perpetual_fee_params'
  _globals['_QUERY'].methods_by_name['UserFeeTier']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UserFeeTier']._serialized_options = b'\202\323\344\223\002)\022\'/dydxprotocol/v4/feetiers/user_fee_tier'
  _globals['_QUERYPERPETUALFEEPARAMSREQUEST']._serialized_start=175
  _globals['_QUERYPERPETUALFEEPARAMSREQUEST']._serialized_end=207
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE']._serialized_start=209
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE']._serialized_end=307
  _globals['_QUERYUSERFEETIERREQUEST']._serialized_start=309
  _globals['_QUERYUSERFEETIERREQUEST']._serialized_end=374
  _globals['_QUERYUSERFEETIERRESPONSE']._serialized_start=376
  _globals['_QUERYUSERFEETIERRESPONSE']._serialized_end=472
  _globals['_QUERY']._serialized_start=475
  _globals['_QUERY']._serialized_end=834
# @@protoc_insertion_point(module_scope)



from v4_proto.dydxprotocol.clob import matches_pb2 as _matches_pb2
from v4_proto.dydxprotocol.clob import order_pb2 as _order_pb2
from v4_proto.dydxprotocol.clob import order_removals_pb2 as _order_removals_pb2
from v4_proto.dydxprotocol.clob import tx_pb2 as _tx_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Operation(_message.Message):
    __slots__ = ("match", "short_term_order_placement", "short_term_order_cancellation", "preexisting_stateful_order")
    MATCH_FIELD_NUMBER: _ClassVar[int]
    SHORT_TERM_ORDER_PLACEMENT_FIELD_NUMBER: _ClassVar[int]
    SHORT_TERM_ORDER_CANCELLATION_FIELD_NUMBER: _ClassVar[int]
    PREEXISTING_STATEFUL_ORDER_FIELD_NUMBER: _ClassVar[int]
    match: _matches_pb2.ClobMatch
    short_term_order_placement: _tx_pb2.MsgPlaceOrder
    short_term_order_cancellation: _tx_pb2.MsgCancelOrder
    preexisting_stateful_order: _order_pb2.OrderId
    def __init__(self, match: _Optional[_Union[_matches_pb2.ClobMatch, _Mapping]] = ..., short_term_order_placement: _Optional[_Union[_tx_pb2.MsgPlaceOrder, _Mapping]] = ..., short_term_order_cancellation: _Optional[_Union[_tx_pb2.MsgCancelOrder, _Mapping]] = ..., preexisting_stateful_order: _Optional[_Union[_order_pb2.OrderId, _Mapping]] = ...) -> None: ...

class InternalOperation(_message.Message):
    __slots__ = ("match", "short_term_order_placement", "preexisting_stateful_order", "order_removal")
    MATCH_FIELD_NUMBER: _ClassVar[int]
    SHORT_TERM_ORDER_PLACEMENT_FIELD_NUMBER: _ClassVar[int]
    PREEXISTING_STATEFUL_ORDER_FIELD_NUMBER: _ClassVar[int]
    ORDER_REMOVAL_FIELD_NUMBER: _ClassVar[int]
    match: _matches_pb2.ClobMatch
    short_term_order_placement: _tx_pb2.MsgPlaceOrder
    preexisting_stateful_order: _order_pb2.OrderId
    order_removal: _order_removals_pb2.OrderRemoval
    def __init__(self, match: _Optional[_Union[_matches_pb2.ClobMatch, _Mapping]] = ..., short_term_order_placement: _Optional[_Union[_tx_pb2.MsgPlaceOrder, _Mapping]] = ..., preexisting_stateful_order: _Optional[_Union[_order_pb2.OrderId, _Mapping]] = ..., order_removal: _Optional[_Union[_order_removals_pb2.OrderRemoval, _Mapping]] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.dydxprotocol.subaccounts import asset_position_pb2 as _asset_position_pb2
from v4_proto.dydxprotocol.subaccounts import perpetual_position_pb2 as _perpetual_position_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubaccountId(_message.Message):
    __slots__ = ("owner", "number")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    owner: str
    number: int
    def __init__(self, owner: _Optional[str] = ..., number: _Optional[int] = ...) -> None: ...

class Subaccount(_message.Message):
    __slots__ = ("id", "asset_positions", "perpetual_positions", "margin_enabled")
    ID_FIELD_NUMBER: _ClassVar[int]
    ASSET_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    MARGIN_ENABLED_FIELD_NUMBER: _ClassVar[int]
    id: SubaccountId
    asset_positions: _containers.RepeatedCompositeFieldContainer[_asset_position_pb2.AssetPosition]
    perpetual_positions: _containers.RepeatedCompositeFieldContainer[_perpetual_position_pb2.PerpetualPosition]
    margin_enabled: bool
    def __init__(self, id: _Optional[_Union[SubaccountId, _Mapping]] = ..., asset_positions: _Optional[_Iterable[_Union[_asset_position_pb2.AssetPosition, _Mapping]]] = ..., perpetual_positions: _Optional[_Iterable[_Union[_perpetual_position_pb2.PerpetualPosition, _Mapping]]] = ..., margin_enabled: bool = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.dydxprotocol.prices import market_param_pb2 as _market_param_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateOracleMarket(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _market_param_pb2.MarketParam
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_market_param_pb2.MarketParam, _Mapping]] = ...) -> None: ...

class MsgCreateOracleMarketResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateMarketPrices(_message.Message):
    __slots__ = ("market_price_updates",)
    class MarketPrice(_message.Message):
        __slots__ = ("market_id", "price")
        MARKET_ID_FIELD_NUMBER: _ClassVar[int]
        PRICE_FIELD_NUMBER: _ClassVar[int]
        market_id: int
        price: int
        def __init__(self, market_id: _Optional[int] = ..., price: _Optional[int] = ...) -> None: ...
    MARKET_PRICE_UPDATES_FIELD_NUMBER: _ClassVar[int]
    market_price_updates: _containers.RepeatedCompositeFieldContainer[MsgUpdateMarketPrices.MarketPrice]
    def __init__(self, market_price_updates: _Optional[_Iterable[_Union[MsgUpdateMarketPrices.MarketPrice, _Mapping]]] = ...) -> None: ...

class MsgUpdateMarketPricesResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateMarketParam(_message.Message):
    __slots__ = ("authority", "market_param")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    MARKET_PARAM_FIELD_NUMBER: _ClassVar[int]
    authority: str
    market_param: _market_param_pb2.MarketParam
    def __init__(self, authority: _Optional[str] = ..., market_param: _Optional[_Union[_market_param_pb2.MarketParam, _Mapping]] = ...) -> None: ...

class MsgUpdateMarketParamResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.bridge import bridge_event_info_pb2 as _bridge_event_info_pb2
from v4_proto.dydxprotocol.bridge import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("event_params", "propose_params", "safety_params", "acknowledged_event_info")
    EVENT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PROPOSE_PARAMS_FIELD_NUMBER: _ClassVar[int]
    SAFETY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    ACKNOWLEDGED_EVENT_INFO_FIELD_NUMBER: _ClassVar[int]
    event_params: _params_pb2.EventParams
    propose_params: _params_pb2.ProposeParams
    safety_params: _params_pb2.SafetyParams
    acknowledged_event_info: _bridge_event_info_pb2.BridgeEventInfo
    def __init__(self, event_params: _Optional[_Union[_params_pb2.EventParams, _Mapping]] = ..., propose_params: _Optional[_Union[_params_pb2.ProposeParams, _Mapping]] = ..., safety_params: _Optional[_Union[_params_pb2.SafetyParams, _Mapping]] = ..., acknowledged_event_info: _Optional[_Union[_bridge_event_info_pb2.BridgeEventInfo, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/ratelimit/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as dydxprotocol_dot_ratelimit_dot_limit__params__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/ratelimit/tx.proto\x12\x16\x64ydxprotocol.ratelimit\x1a\x17\x63osmos/msg/v1/msg.proto\x1a)dydxprotocol/ratelimit/limit_params.proto\x1a\x14gogoproto/gogo.proto\"w\n\x11MsgSetLimitParams\x12\x11\n\tauthority\x18\x01 \x01(\t\x12?\n\x0climit_params\x18\x02 \x01(\x0b\x32#.dydxprotocol.ratelimit.LimitParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgSetLimitParamsResponse2u\n\x03Msg\x12n\n\x0eSetLimitParams\x12).dydxprotocol.ratelimit.MsgSetLimitParams\x1a\x31.dydxprotocol.ratelimit.MsgSetLimitParamsResponseB=Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.ratelimit.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/types'
  _globals['_MSGSETLIMITPARAMS'].fields_by_name['limit_params']._loaded_options = None
  _globals['_MSGSETLIMITPARAMS'].fields_by_name['limit_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETLIMITPARAMS']._loaded_options = None
  _globals['_MSGSETLIMITPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETLIMITPARAMS']._serialized_start=149
  _globals['_MSGSETLIMITPARAMS']._serialized_end=268
  _globals['_MSGSETLIMITPARAMSRESPONSE']._serialized_start=270
  _globals['_MSGSETLIMITPARAMSRESPONSE']._serialized_end=297
  _globals['_MSG']._serialized_start=299
  _globals['_MSG']._serialized_end=416
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/daemons/bridge/bridge.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.bridge import bridge_event_pb2 as dydxprotocol_dot_bridge_dot_bridge__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dydxprotocol/daemons/bridge/bridge.proto\x12\x1b\x64ydxprotocol.daemons.bridge\x1a\x14gogoproto/gogo.proto\x1a&dydxprotocol/bridge/bridge_event.proto\"W\n\x16\x41\x64\x64\x42ridgeEventsRequest\x12=\n\rbridge_events\x18\x01 \x03(\x0b\x32 .dydxprotocol.bridge.BridgeEventB\x04\xc8\xde\x1f\x00\"\x19\n\x17\x41\x64\x64\x42ridgeEventsResponse2\x8d\x01\n\rBridgeService\x12|\n\x0f\x41\x64\x64\x42ridgeEvents\x12\x33.dydxprotocol.daemons.bridge.AddBridgeEventsRequest\x1a\x34.dydxprotocol.daemons.bridge.AddBridgeEventsResponseB>Z<github.com/dydxprotocol/v4-chain/protocol/daemons/bridge/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.daemons.bridge.bridge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/daemons/bridge/api'
  _globals['_ADDBRIDGEEVENTSREQUEST'].fields_by_name['bridge_events']._loaded_options = None
  _globals['_ADDBRIDGEEVENTSREQUEST'].fields_by_name['bridge_events']._serialized_options = b'\310\336\037\000'
  _globals['_ADDBRIDGEEVENTSREQUEST']._serialized_start=135
  _globals['_ADDBRIDGEEVENTSREQUEST']._serialized_end=222
  _globals['_ADDBRIDGEEVENTSRESPONSE']._serialized_start=224
  _globals['_ADDBRIDGEEVENTSRESPONSE']._serialized_end=249
  _globals['_BRIDGESERVICE']._serialized_start=252
  _globals['_BRIDGESERVICE']._serialized_end=393
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NumShares(_message.Message):
    __slots__ = ("num_shares",)
    NUM_SHARES_FIELD_NUMBER: _ClassVar[int]
    num_shares: bytes
    def __init__(self, num_shares: _Optional[bytes] = ...) -> None: ...

class OwnerShare(_message.Message):
    __slots__ = ("owner", "shares")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    SHARES_FIELD_NUMBER: _ClassVar[int]
    owner: str
    shares: NumShares
    def __init__(self, owner: _Optional[str] = ..., shares: _Optional[_Union[NumShares, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EpochInfo(_message.Message):
    __slots__ = ("name", "next_tick", "duration", "current_epoch", "current_epoch_start_block", "is_initialized", "fast_forward_next_tick")
    NAME_FIELD_NUMBER: _ClassVar[int]
    NEXT_TICK_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    CURRENT_EPOCH_FIELD_NUMBER: _ClassVar[int]
    CURRENT_EPOCH_START_BLOCK_FIELD_NUMBER: _ClassVar[int]
    IS_INITIALIZED_FIELD_NUMBER: _ClassVar[int]
    FAST_FORWARD_NEXT_TICK_FIELD_NUMBER: _ClassVar[int]
    name: str
    next_tick: int
    duration: int
    current_epoch: int
    current_epoch_start_block: int
    is_initialized: bool
    fast_forward_next_tick: bool
    def __init__(self, name: _Optional[str] = ..., next_tick: _Optional[int] = ..., duration: _Optional[int] = ..., current_epoch: _Optional[int] = ..., current_epoch_start_block: _Optional[int] = ..., is_initialized: bool = ..., fast_forward_next_tick: bool = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.bank.v1beta1 import bank_pb2 as _bank_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("params", "balances", "supply", "denom_metadata", "send_enabled")
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    BALANCES_FIELD_NUMBER: _ClassVar[int]
    SUPPLY_FIELD_NUMBER: _ClassVar[int]
    DENOM_METADATA_FIELD_NUMBER: _ClassVar[int]
    SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    params: _bank_pb2.Params
    balances: _containers.RepeatedCompositeFieldContainer[Balance]
    supply: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    denom_metadata: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Metadata]
    send_enabled: _containers.RepeatedCompositeFieldContainer[_bank_pb2.SendEnabled]
    def __init__(self, params: _Optional[_Union[_bank_pb2.Params, _Mapping]] = ..., balances: _Optional[_Iterable[_Union[Balance, _Mapping]]] = ..., supply: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., denom_metadata: _Optional[_Iterable[_Union[_bank_pb2.Metadata, _Mapping]]] = ..., send_enabled: _Optional[_Iterable[_Union[_bank_pb2.SendEnabled, _Mapping]]] = ...) -> None: ...

class Balance(_message.Message):
    __slots__ = ("address", "coins")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, address: _Optional[str] = ..., coins: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as _vest_entry_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("vest_entries",)
    VEST_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    vest_entries: _containers.RepeatedCompositeFieldContainer[_vest_entry_pb2.VestEntry]
    def __init__(self, vest_entries: _Optional[_Iterable[_Union[_vest_entry_pb2.VestEntry, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/authz/v1beta1/genesis.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x14gogoproto/gogo.proto\x1a cosmos/authz/v1beta1/authz.proto\x1a\x11\x61mino/amino.proto\"Z\n\x0cGenesisState\x12J\n\rauthorization\x18\x01 \x03(\x0b\x32(.cosmos.authz.v1beta1.GrantAuthorizationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _globals['_GENESISSTATE'].fields_by_name['authorization']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['authorization']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=135
  _globals['_GENESISSTATE']._serialized_end=225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/process_proposer_matches_events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.clob import order_pb2 as dydxprotocol_dot_clob_dot_order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dydxprotocol/clob/process_proposer_matches_events.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a\x1d\x64ydxprotocol/clob/order.proto\"\xc9\x04\n\x1cProcessProposerMatchesEvents\x12\x46\n\x1aplaced_long_term_order_ids\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x06\x18\x01\xc8\xde\x1f\x00\x12\x44\n\x1a\x65xpired_stateful_order_ids\x18\x02 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12H\n\x1eorder_ids_filled_in_last_block\x18\x03 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12R\n&placed_stateful_cancellation_order_ids\x18\x04 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x06\x18\x01\xc8\xde\x1f\x00\x12\x44\n\x1aremoved_stateful_order_ids\x18\x05 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12W\n-conditional_order_ids_triggered_in_last_block\x18\x06 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12H\n\x1cplaced_conditional_order_ids\x18\x07 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x06\x18\x01\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x08 \x01(\rB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.process_proposer_matches_events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['placed_long_term_order_ids']._loaded_options = None
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['placed_long_term_order_ids']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['expired_stateful_order_ids']._loaded_options = None
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['expired_stateful_order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['order_ids_filled_in_last_block']._loaded_options = None
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['order_ids_filled_in_last_block']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['placed_stateful_cancellation_order_ids']._loaded_options = None
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['placed_stateful_cancellation_order_ids']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['removed_stateful_order_ids']._loaded_options = None
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['removed_stateful_order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['conditional_order_ids_triggered_in_last_block']._loaded_options = None
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['conditional_order_ids_triggered_in_last_block']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['placed_conditional_order_ids']._loaded_options = None
  _globals['_PROCESSPROPOSERMATCHESEVENTS'].fields_by_name['placed_conditional_order_ids']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_PROCESSPROPOSERMATCHESEVENTS']._serialized_start=132
  _globals['_PROCESSPROPOSERMATCHESEVENTS']._serialized_end=717
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/blocktime/blocktime.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&dydxprotocol/blocktime/blocktime.proto\x12\x16\x64ydxprotocol.blocktime\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"T\n\tBlockInfo\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\x37\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xdb\x01\n\x0f\x41llDowntimeInfo\x12\x43\n\x05infos\x18\x01 \x03(\x0b\x32\x34.dydxprotocol.blocktime.AllDowntimeInfo.DowntimeInfo\x1a\x82\x01\n\x0c\x44owntimeInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12;\n\nblock_info\x18\x02 \x01(\x0b\x32!.dydxprotocol.blocktime.BlockInfoB\x04\xc8\xde\x1f\x00\x42=Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.blocktime.blocktime_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/types'
  _globals['_BLOCKINFO'].fields_by_name['timestamp']._loaded_options = None
  _globals['_BLOCKINFO'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['duration']._loaded_options = None
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['block_info']._loaded_options = None
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['block_info']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKINFO']._serialized_start=153
  _globals['_BLOCKINFO']._serialized_end=237
  _globals['_ALLDOWNTIMEINFO']._serialized_start=240
  _globals['_ALLDOWNTIMEINFO']._serialized_end=459
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO']._serialized_start=329
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO']._serialized_end=459
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/listing/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/listing/tx.proto\x12\x14\x64ydxprotocol.listing\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\"q\n\x14MsgSetMarketsHardCap\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x1c\n\x14hard_cap_for_markets\x18\x02 \x01(\r:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgSetMarketsHardCapResponse\"\xe4\x01\n\x1dMsgCreateMarketPermissionless\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12=\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"\'\n%MsgCreateMarketPermissionlessResponse2\x8b\x02\n\x03Msg\x12s\n\x11SetMarketsHardCap\x12*.dydxprotocol.listing.MsgSetMarketsHardCap\x1a\x32.dydxprotocol.listing.MsgSetMarketsHardCapResponse\x12\x8e\x01\n\x1a\x43reateMarketPermissionless\x12\x33.dydxprotocol.listing.MsgCreateMarketPermissionless\x1a;.dydxprotocol.listing.MsgCreateMarketPermissionlessResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.listing.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/types'
  _globals['_MSGSETMARKETSHARDCAP'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETMARKETSHARDCAP'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMARKETSHARDCAP']._loaded_options = None
  _globals['_MSGSETMARKETSHARDCAP']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATEMARKETPERMISSIONLESS'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGCREATEMARKETPERMISSIONLESS'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._loaded_options = None
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGSETMARKETSHARDCAP']._serialized_start=172
  _globals['_MSGSETMARKETSHARDCAP']._serialized_end=285
  _globals['_MSGSETMARKETSHARDCAPRESPONSE']._serialized_start=287
  _globals['_MSGSETMARKETSHARDCAPRESPONSE']._serialized_end=317
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._serialized_start=320
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._serialized_end=548
  _globals['_MSGCREATEMARKETPERMISSIONLESSRESPONSE']._serialized_start=550
  _globals['_MSGCREATEMARKETPERMISSIONLESSRESPONSE']._serialized_end=589
  _globals['_MSG']._serialized_start=592
  _globals['_MSG']._serialized_end=859
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.vault import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as _vault_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgDepositToVault(_message.Message):
    __slots__ = ("vault_id", "subaccount_id", "quote_quantums")
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    vault_id: _vault_pb2.VaultId
    subaccount_id: _subaccount_pb2.SubaccountId
    quote_quantums: bytes
    def __init__(self, vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., quote_quantums: _Optional[bytes] = ...) -> None: ...

class MsgDepositToVaultResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateDefaultQuotingParams(_message.Message):
    __slots__ = ("authority", "default_quoting_params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_QUOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    default_quoting_params: _params_pb2.QuotingParams
    def __init__(self, authority: _Optional[str] = ..., default_quoting_params: _Optional[_Union[_params_pb2.QuotingParams, _Mapping]] = ...) -> None: ...

class MsgUpdateDefaultQuotingParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSetVaultQuotingParams(_message.Message):
    __slots__ = ("authority", "vault_id", "quoting_params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    vault_id: _vault_pb2.VaultId
    quoting_params: _params_pb2.QuotingParams
    def __init__(self, authority: _Optional[str] = ..., vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., quoting_params: _Optional[_Union[_params_pb2.QuotingParams, _Mapping]] = ...) -> None: ...

class MsgSetVaultQuotingParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.google.api import http_pb2 as _http_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
HTTP_FIELD_NUMBER: _ClassVar[int]
http: _descriptor.FieldDescriptor
